### Changelog

All notable changes to this project will be documented in this file. Dates are displayed in UTC.

Generated by [`auto-changelog`](https://github.com/CookPete/auto-changelog).

#### 1.0.0

> 3 January 2025

- Initial commit [`fc49393`](https://github.com/hemna/aprsd-admin-extension/commit/fc493938638ad9ae717021664edd63f2f809e70c)
- Initial commit of the admin web UI [`b11cc3c`](https://github.com/hemna/aprsd-admin-extension/commit/b11cc3c550cf59e84607c52258b632d38ae42c43)
- Got content working again [`b023397`](https://github.com/hemna/aprsd-admin-extension/commit/b0233978c44ab5b3ca0787254281abcc9aa985a1)
- deleted pyc file [`6d30868`](https://github.com/hemna/aprsd-admin-extension/commit/6d30868f7370ecd45e5b813f14e6433fcfde65bc)
- updated pre-commit hooks. [`f8a315d`](https://github.com/hemna/aprsd-admin-extension/commit/f8a315dfd27d362d309126fbec8a19e610805fcc)
